@@ -2,6 +2,7 @@ import fnmatch
 import os
 import pprint
 import subprocess
+import sys
 
 from . import creationutils
 
@@ -26,16 +27,25 @@ class Converter(object):
 def converter_blend_bam(config, srcdir, dstdir, assets):
     import blend2bam
 
+    verbose = config['general']['verbose']
+
+    blend2bam_version = [int(i) for i in blend2bam.__version__.split('.')]
+
     remaining_assets = set(assets)
 
     default_mat_mode = config['blend2bam']['material_mode']
     default_phy_engine = config['blend2bam']['physics_engine']
     default_pipeline = config['blend2bam']['pipeline']
+    default_animations = config['blend2bam']['animations']
     runs = []
 
     for override in config['blend2bam']['overrides']:
         files = {
-            i for i in assets if fnmatch.fnmatchcase(i, override['pattern'])
+            i for i in assets
+            if (
+                fnmatch.fnmatchcase(i, override['pattern'])
+                or fnmatch.fnmatchcase(os.path.basename(i), override['pattern'])
+            )
         }
 
         if not files:
@@ -46,10 +56,12 @@ def converter_blend_bam(config, srcdir, dstdir, assets):
             'material_mode': override.get('material_mode', default_mat_mode),
             'physics_engine': override.get('physics_engine', default_phy_engine),
             'pipeline': override.get('pipeline', default_pipeline),
+            'animations': override.get('animations', default_animations),
         })
-        print('blend2bam: Using the following override\n{}'.format(
-            pprint.pformat(runs[-1])
-        ))
+        if verbose:
+            print('blend2bam: Using the following override\n{}'.format(
+                pprint.pformat(runs[-1])
+            ))
         remaining_assets -= files
 
     runs.append({
@@ -57,20 +69,32 @@ def converter_blend_bam(config, srcdir, dstdir, assets):
         'material_mode': default_mat_mode,
         'physics_engine': default_phy_engine,
         'pipeline': default_pipeline,
+        'animations': default_animations,
     })
 
 
     for run in runs:
         args = [
-            'blend2bam',
+            sys.executable,
+            '-m', 'blend2bam',
             '--srcdir', f'"{srcdir}"',
             '--material-mode', run['material_mode'],
             '--physics-engine', run['physics_engine'],
             '--pipeline', run['pipeline'],
         ]
 
-        if config['blender']['use_last_path']:
-            blenderdir = os.path.dirname(config['blender']['last_path'])
+        if blend2bam_version[0] != 0 or blend2bam_version[1] >= 17:
+            args += [
+                '--animations', run['animations']
+            ]
+        elif run['animations'] != default_animations:
+            raise RuntimeError(
+                'blend2bam >= 0.17 is required for animations values other'
+                f' than "{default_animations}"'
+            )
+
+        blenderdir = config['blend2bam']['blender_dir']
+        if blenderdir:
             args += [
                 '--blender-dir', f'"{blenderdir}"',
             ]
@@ -79,7 +103,8 @@ def converter_blend_bam(config, srcdir, dstdir, assets):
             f'"{dstdir}"'
         ]
 
-        print("Calling blend2bam: {}".format(' '.join(args)))
+        if verbose:
+            print(f'Calling blend2bam: {" ".join(args)}')
 
         subprocess.check_call(args, env=os.environ.copy(), stdout=subprocess.DEVNULL)
 
@@ -89,7 +114,8 @@ def converter_blend_bam(config, srcdir, dstdir, assets):
     '.fbx', '.dae',
     '.ply',
 ])
-def converter_native_bam(_config, srcdir, dstdir, assets):
+def converter_native_bam(config, srcdir, dstdir, assets):
+    verbose = config['general']['verbose']
     processes = []
     for asset in assets:
         if asset.endswith('.mtl'):
@@ -104,7 +130,8 @@ def converter_native_bam(_config, srcdir, dstdir, assets):
             dst
         ]
 
-        # print("Calling native2bam: {}".format(' '.join(args)))
+        if verbose:
+            print(f'Calling native2bam: {" ".join(args)}')
         processes.append(subprocess.Popen(args, env=os.environ.copy(), stdout=subprocess.DEVNULL))
 
     for proc in processes:
@@ -134,32 +161,3 @@ def create_git(projectdir, config):
     if add_export_dir:
         with open(gitignorepath, 'a') as gitignorefile:
             gitignorefile.write(config['build']['export_dir'])
-
-def create_blender(projectdir, config):
-    # Update config
-    ignore_patterns = ['*.blend1', '*.blend2']
-    for pattern in ignore_patterns:
-        if pattern not in config['build']['ignore_patterns']:
-            config['build']['ignore_patterns'].append(pattern)
-
-    if 'blend2bam' not in config['build']['converters']:
-        project_layer = config.layers['project']
-        if 'build' not in project_layer:
-            project_layer['build'] = {}
-        if 'converters' not in project_layer['build']:
-            project_layer['build']['converters'] = []
-        project_layer['build']['converters'].append('blend2bam')
-
-    config.write()
-
-    # Update requirements.txt
-    add_blend2bam_req = True
-    reqpath = os.path.join(projectdir, 'requirements.txt')
-    with open(reqpath, 'r') as reqfile:
-        for line in reqfile.readlines():
-            if line.startswith('panda3d-blend2bam'):
-                add_blend2bam_req = False
-
-    if add_blend2bam_req:
-        with open(reqpath, 'a') as reqfile:
-            reqfile.write('panda3d-blend2bam')
